==> jc-1.4.0.tar.gz: soot/coffi/local__5fvariable__5ftable__5fentry.h <==
// class soot.coffi.local_variable_table_entry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 416483cac482897c soot_coffi_local__5fvariable__5ftable__5fentry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_
#define _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$object;

typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods;
typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable;
typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype;

// Constructors
extern void _jc_soot_coffi_local__5fvariable__5ftable__5fentry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_coffi_local__5fvariable__5ftable__5fentry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_local__5fvariable__5ftable__5fentry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *);
};

// Vtable
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods	soot_coffi_local__5fvariable__5ftable__5fentry;
};

// Vtype
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype {
	_jc_type			type;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs {
    _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs	soot_coffi_local__5fvariable__5ftable__5fentry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs {
	jint	start__5fpc;
	jint	length;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs	soot_coffi_local__5fvariable__5ftable__5fentry;
};

// Object instance structure
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object {
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype	*vtype;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype _jc_soot_coffi_local__5fvariable__5ftable__5fentry$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_local__5fvariable__5ftable__5fentry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_local__5fvariable__5ftable__5fentry$class_object;

#endif	/* _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/local__5fvariable__5ftable__5fentry.h <==
// class soot.coffi.local_variable_table_entry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 416483cac482897c soot_coffi_local__5fvariable__5ftable__5fentry

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_
#define _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs;
typedef struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$object;

typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods;
typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable;
typedef const struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype;

// Constructors
extern void _jc_soot_coffi_local__5fvariable__5ftable__5fentry$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_coffi_local__5fvariable__5ftable__5fentry$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_local__5fvariable__5ftable__5fentry$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vmethods	soot_coffi_local__5fvariable__5ftable__5fentry;
};

// Vtype
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype {
	_jc_type			type;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs {
    _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_refs	soot_coffi_local__5fvariable__5ftable__5fentry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs {
	jint	start__5fpc;
	jint	length;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_local__5fvariable__5ftable__5fentry$sub_nonrefs	soot_coffi_local__5fvariable__5ftable__5fentry;
};

// Object instance structure
struct _jc_soot_coffi_local__5fvariable__5ftable__5fentry$object {
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype	*vtype;
	_jc_soot_coffi_local__5fvariable__5ftable__5fentry$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_local__5fvariable__5ftable__5fentry$vtype _jc_soot_coffi_local__5fvariable__5ftable__5fentry$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_local__5fvariable__5ftable__5fentry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_local__5fvariable__5ftable__5fentry$class_object;

#endif	/* _JC_soot_coffi_local__5fvariable__5ftable__5fentry_H_ */
